referrerpolicy=no-referrer-when-downgrade

IssuanceCurve

Trait IssuanceCurve 

pub trait IssuanceCurve<Balance> {
    // Required method
    fn issue(total_issuance: Balance, elapsed_millis: u64) -> Balance;
}
Computes new token issuance for a given time period.

Unlike super::EraPayout, this trait does not depend on staking state. Issuance is purely a function of total supply and elapsed time.

Required Methods

fn issue(total_issuance: Balance, elapsed_millis: u64) -> Balance

Compute how much new tokens to mint for the given period.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<Balance: Default> IssuanceCurve<Balance> for ()

Source

fn issue(_total_issuance: Balance, _elapsed_millis: u64) -> Balance

Implementors