pub trait IssuanceCurve<Balance> {
// Required method
fn issue(total_issuance: Balance, elapsed_millis: u64) -> Balance;
}Expand description
Computes new token issuance for a given time period.
Unlike super::EraPayout, this trait does not depend on staking state. Issuance is
purely a function of total supply and elapsed time.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.